package com.jz.dmp.modules.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.jz.common.constant.GatewayApiConstant;
import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.utils.web.HttpClientUtils;
import com.jz.common.utils.web.SessionUtils;
import com.jz.dmp.modules.controller.dataService.bean.*;
import com.jz.dmp.modules.service.DmpOrgMangeService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

/**
 * @ClassName: DmpOrgMangeServiceImpl
 * @Description: 数据服务组织管理
 * @Author: Bellamy
 * @Date 2021/1/15
 * @Version 1.0
 */
@Service("dmpOrgMangeService")
public class DmpOrgMangeServiceImpl implements DmpOrgMangeService {

    private static Logger logger = LoggerFactory.getLogger(DmpOrgMangeServiceImpl.class);

    @Value("${spring.gateway-url}")
    private String gatewayUrl;

    /**
     * 列表分页查询
     *
     * @return
     * @author Bellamy
     * @since 2021-01-16
     */
    @Override
    public JsonResult queryOrgListPage(OrganizationManageListQueryReq req) throws Exception {
        String url = gatewayUrl + GatewayApiConstant.orgListPage;

        if (StringUtils.isNotEmpty(req.getOrgName())) {
            req.setOrgName(req.getOrgName().trim());
        }
        JsonResult result = GatewayApiConstant.postRequest2GetData(url, JSONObject.toJSONString(req));
        return result;
    }

    /**
     * 删除组织
     *
     * @return
     * @author Bellamy
     * @since 2021-01-16
     */
    @Override
    public JsonResult delOrgById(long id) throws Exception {
        Map params = new HashMap();
        params.put("id", id);
        String url = gatewayUrl + GatewayApiConstant.delOrg;
        JsonResult result = GatewayApiConstant.getRequest2GetData(url, params);
        return result;
    }

    /**
     * 新增组织
     *
     * @return
     * @author Bellamy
     * @since 2021-01-16
     */
    @Override
    public JsonResult addOrg(OrganizationManageAddReq req) throws Exception {
        String url = gatewayUrl + GatewayApiConstant.addOrg;
        req.setCreateUser(SessionUtils.getCurrentUserName());
        JsonResult result = GatewayApiConstant.postRequest2GetData(url, JSONObject.toJSONString(req));
        return result;
    }

    /**
     * 编辑组织
     *
     * @return
     * @author Bellamy
     * @since 2021-01-16
     */
    @Override
    public JsonResult updateOrg(OrganizationManageUpdateReq req) throws Exception {
        String url = gatewayUrl + GatewayApiConstant.addOrg;

        req.setCreateUser(SessionUtils.getCurrentUserName());
        JsonResult result = GatewayApiConstant.postRequest2GetData(url, JSONObject.toJSONString(req));
        return result;
    }

    /**
     * 根据组织id获取组织详情
     *
     * @author Bellamy
     * @since 2021-01-18
     */
    @Override
    public JsonResult getOrgInfoByOrgId(String id) throws Exception {
        String url = gatewayUrl + GatewayApiConstant.orgDetail;
        OrganizationManageDetailQueryReq req = new OrganizationManageDetailQueryReq();
        req.setId(Long.valueOf(id));
        JsonResult result = GatewayApiConstant.postRequest2GetData(url, JSONObject.toJSONString(req));
        return result;
    }
}
